﻿/*
* Copyright 2011 Benjamin Thomas Daniel Newman
*
*   Licensed under the Apache License, Version 2.0 (the "License");
*   you may not use this file except in compliance with the License.
*   You may obtain a copy of the License at
*
*       http://www.apache.org/licenses/LICENSE-2.0
*
*   Unless required by applicable law or agreed to in writing, software
*   distributed under the License is distributed on an "AS IS" BASIS,
*   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*   See the License for the specific language governing permissions and
*   limitations under the License.
*/

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;

namespace eyurale
{
    /* Class to handle strings sent by the CMUcam3 with the euryale firmware*/
    public static class EuryaleStrings
    {
        public static string Prompt() { return ":"; }
        public static string StartingUp() { return "euryale: starting up..."; }
        public static string AskForDemo() { return "euryale: press button for demo mode:"; }
        public static string InDemoMode() { return "euryale: running in demo mode"; }
        public static string WaitingToStabalize() { return "euryale: waiting for image to stabilize..."; }
        public static string RreadyForColor() { return "euryale: hold up colored object and press button"; }
        public static string GrabbingColor() { return "euryale: grabbing color..."; }
        public static string LostObject() { return "euryale: tracking: lost object"; }
        public static string DemoMode() { return "euryale: running in demo mode"; }
        public static string Tracking() { return "euryale: tracking:"; }
        public static string Color() { return "euryale: color:"; }

        /* Takes the position sring */
        public static string GetCentroid(string str)
        {
            return Regex.Replace(str, ".*centroid=\\[([0-9]+),([0-9]+)\\].+",
                "$1, $2");
        }

        /* Takes the position sring */
        public static string GetBoundingBox(string str)
        {
            return Regex.Replace(str, ".*bounding-box=\\[([0-9]+),([0-9]+),([0-9]+),([0-9]+)\\].*",
    "$1, $2, $3, $4");
        }

        /* Takes the position sring */
        public static string GetNumPix(string str)
        {
            return Regex.Replace(str, ".*num-pix=([0-9]*).*", "$1");
        }

        /* Takes the position sring */
        public static string GetDensity(string str)
        {
            return Regex.Replace(str, ".*density=([0-9]*).*", "$1");
        }

        public static string GetColor(string str, string tag)
        {
            return Regex.Replace(str, ".*" + tag + "=\\[([0-9]+),([0-9]+),([0-9]+)\\].*",
                "$1, $2, $3");
        }

        /* Accepts strings with or without prompt */
        public static bool StartsWith(string line, string str)
        {
            if(line.StartsWith(str) || line.StartsWith(Prompt() + str))
                return true;
            else 
                return false;
        }
    }
}
